@@ -385,8 +385,6 @@ gdk_gl_context_create_egl_context (GdkGLContext *context,
   if (ctx == EGL_NO_CONTEXT)
     return 0;
 
-  GDK_DISPLAY_DEBUG (display, OPENGL, "Created EGL context[%p]", ctx);
-
   priv->egl_context = ctx;
   gdk_gl_context_set_version (context, &supported_versions[j]);
   gdk_gl_context_set_is_legacy (context, legacy);
@@ -764,7 +762,7 @@ gdk_gl_context_class_init (GdkGLContextClass *klass)
   draw_context_class->surface_resized = gdk_gl_context_surface_resized;
 
   /**
-   * GdkGLContext:shared-context: (attributes org.gtk.Property.get=gdk_gl_context_get_shared_context)
+   * GdkGLContext:shared-context:
    *
    * Always %NULL
    *
@@ -783,7 +781,7 @@ gdk_gl_context_class_init (GdkGLContextClass *klass)
                          G_PARAM_DEPRECATED);
 
   /**
-   * GdkGLContext:allowed-apis: (attributes org.gtk.Property.get=gdk_gl_context_get_allowed_apis org.gtk.Property.gdk_gl_context_set_allowed_apis)
+   * GdkGLContext:allowed-apis:
    *
    * The allowed APIs.
    *
@@ -798,7 +796,7 @@ gdk_gl_context_class_init (GdkGLContextClass *klass)
                         G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GdkGLContext:api: (attributes org.gtk.Property.get=gdk_gl_context_get_api)
+   * GdkGLContext:api:
    *
    * The API currently in use.
    *
@@ -1250,7 +1248,7 @@ gdk_gl_context_is_shared (GdkGLContext *self,
 }
 
 /**
- * gdk_gl_context_set_allowed_apis: (attributes org.gtk.Method.set_property=allowed-apis)
+ * gdk_gl_context_set_allowed_apis:
  * @self: a GL context
  * @apis: the allowed APIs
  *
@@ -1281,7 +1279,7 @@ gdk_gl_context_set_allowed_apis (GdkGLContext *self,
 }
 
 /**
- * gdk_gl_context_get_allowed_apis: (attributes org.gtk.Method.get_property=allowed-apis)
+ * gdk_gl_context_get_allowed_apis:
  * @self: a GL context
  *
  * Gets the allowed APIs set via gdk_gl_context_set_allowed_apis().
@@ -1301,7 +1299,7 @@ gdk_gl_context_get_allowed_apis (GdkGLContext *self)
 }
 
 /**
- * gdk_gl_context_get_api: (attributes org.gtk.Method.get_property=api)
+ * gdk_gl_context_get_api:
  * @self: a GL context
  *
  * Gets the API currently in use.
@@ -1795,22 +1793,20 @@ gdk_gl_context_check_extensions (GdkGLContext *context)
     {
       int i, max_texture_size;
       glGetIntegerv (GL_MAX_TEXTURE_SIZE, &max_texture_size);
-      gdk_debug_message ("%s version: %d.%d (%s)\n"
-                         "* GLSL version: %s\n"
-                         "* Max texture size: %d\n",
+      gdk_debug_message ("%s version: %d.%d (%s)",
                          gdk_gl_context_get_use_es (context) ? "OpenGL ES" : "OpenGL",
                          gdk_gl_version_get_major (&priv->gl_version), gdk_gl_version_get_minor (&priv->gl_version),
-                         priv->is_legacy ? "legacy" : "core",
-                         glGetString (GL_SHADING_LANGUAGE_VERSION),
-                         max_texture_size);
+                         priv->is_legacy ? "legacy" : "core");
+      gdk_debug_message ("GLSL version: %s", glGetString (GL_SHADING_LANGUAGE_VERSION));
+      gdk_debug_message ("Max texture size: %d", max_texture_size);
       gdk_debug_message ("Enabled features (use GDK_GL_DISABLE env var to disable):");
       for (i = 0; i < G_N_ELEMENTS (gdk_gl_feature_keys); i++)
         {
           gdk_debug_message ("    %s: %s",
                              gdk_gl_feature_keys[i].key,
-                             (priv->features & gdk_gl_feature_keys[i].value) ? "YES" :
+                             (priv->features & gdk_gl_feature_keys[i].value) ? "✓" :
                              ((disabled_features & gdk_gl_feature_keys[i].value) ? "disabled via env var" :
-                             (((supported_features & gdk_gl_feature_keys[i].value) == 0) ? "not supported" :
+                             (((supported_features & gdk_gl_feature_keys[i].value) == 0) ? "✗" :
                              "Hum, what? This should not happen.")));
         }
     }
@@ -1913,7 +1909,7 @@ gdk_gl_context_get_surface (GdkGLContext *context)
 }
 
 /**
- * gdk_gl_context_get_shared_context: (attributes org.gtk.Method.get_property=shared-context)
+ * gdk_gl_context_get_shared_context:
  * @context: a `GdkGLContext`
  *
  * Used to retrieves the `GdkGLContext` that this @context share data with.
@@ -2217,6 +2213,7 @@ gdk_gl_backend_use (GdkGLBackend backend_type)
   g_assert (the_gl_backend_type == backend_type);
 }
 
+#if defined(HAVE_EGL) && defined(HAVE_DMABUF)
 static guint
 gdk_gl_context_import_dmabuf_for_target (GdkGLContext    *self,
                                          int              width,
@@ -2224,7 +2221,6 @@ gdk_gl_context_import_dmabuf_for_target (GdkGLContext    *self,
                                          const GdkDmabuf *dmabuf,
                                          int              target)
 {
-#if defined(HAVE_EGL) && defined(HAVE_DMABUF)
   GdkDisplay *display = gdk_gl_context_get_display (self);
   EGLImage image;
   guint texture_id;
@@ -2232,8 +2228,7 @@ gdk_gl_context_import_dmabuf_for_target (GdkGLContext    *self,
   image = gdk_dmabuf_egl_create_image (display,
                                        width,
                                        height,
-                                       dmabuf,
-                                       target);
+                                       dmabuf);
   if (image == EGL_NO_IMAGE)
     return 0;
 
@@ -2246,10 +2241,8 @@ gdk_gl_context_import_dmabuf_for_target (GdkGLContext    *self,
   eglDestroyImageKHR (gdk_display_get_egl_display (display), image);
 
   return texture_id;
-#else
-  return 0;
-#endif
 }
+#endif
 
 guint
 gdk_gl_context_import_dmabuf (GdkGLContext    *self,
@@ -2258,10 +2251,11 @@ gdk_gl_context_import_dmabuf (GdkGLContext    *self,
                               const GdkDmabuf *dmabuf,
                               gboolean        *external)
 {
+#if defined(HAVE_EGL) && defined(HAVE_DMABUF)
   GdkDisplay *display = gdk_gl_context_get_display (self);
   guint texture_id;
 
-  gdk_display_init_dmabuf (display);
+  gdk_dmabuf_egl_init (display);
 
   if (gdk_dmabuf_formats_contains (display->egl_dmabuf_formats, dmabuf->fourcc, dmabuf->modifier))
     {
@@ -2352,6 +2346,9 @@ gdk_gl_context_import_dmabuf (GdkGLContext    *self,
       *external = target == GL_TEXTURE_EXTERNAL_OES;
       return texture_id;
     }
+#else
+  return 0;
+#endif
 }
 
 gboolean
