@@ -35,7 +35,7 @@
 #include <math.h>
 
 #ifdef GDK_RENDERING_VULKAN
-static const GdkDebugKey gsk_vulkan_feature_keys[] = {
+static const GdkDebugKey gdk_vulkan_feature_keys[] = {
   { "dmabuf", GDK_VULKAN_FEATURE_DMABUF, "Never import Dmabufs" },
   { "ycbcr", GDK_VULKAN_FEATURE_YCBCR, "Do not support Ycbcr textures (also disables dmabufs)" },
   { "semaphore-export", GDK_VULKAN_FEATURE_SEMAPHORE_EXPORT, "Disable sync of exported dmabufs" },
@@ -405,6 +405,15 @@ gdk_vulkan_context_dispose (GObject *gobject)
   G_OBJECT_CLASS (gdk_vulkan_context_parent_class)->dispose (gobject);
 }
 
+static void
+gdk_vulkan_context_get_image_size (GdkVulkanContext *context,
+                                   VkExtent2D       *size)
+{
+  GDK_VULKAN_CONTEXT_GET_CLASS (context)->get_image_size (context,
+                                                          &size->width,
+                                                          &size->height);
+}
+
 static gboolean
 gdk_vulkan_context_check_swapchain (GdkVulkanContext  *context,
                                     GError           **error)
@@ -417,8 +426,13 @@ gdk_vulkan_context_check_swapchain (GdkVulkanContext  *context,
   VkSwapchainKHR new_swapchain;
   VkResult res;
   VkDevice device;
+  VkExtent2D size;
   guint i;
 
+  GDK_DEBUG (VULKAN, "(Re)creating the swapchain for surface of size %dx%d",
+             gdk_surface_get_width (surface),
+             gdk_surface_get_height (surface));
+
   device = gdk_vulkan_context_get_device (context);
 
   /*
@@ -457,6 +471,8 @@ gdk_vulkan_context_check_swapchain (GdkVulkanContext  *context,
   GDK_DEBUG (VULKAN, "Using surface present mode %s",
              surface_present_mode_to_string (present_mode));
 
+  gdk_vulkan_context_get_image_size (context, &size);
+
   /*
    * Per https://www.khronos.org/registry/vulkan/specs/1.0-wsi_extensions/xhtml/vkspec.html#VkSurfaceCapabilitiesKHR
    * the current extent may assume a special value, meaning that the extent should assume whatever
@@ -464,10 +480,34 @@ gdk_vulkan_context_check_swapchain (GdkVulkanContext  *context,
    */
   if (capabilities.currentExtent.width == -1 || capabilities.currentExtent.height == -1)
     {
-      double scale = gdk_surface_get_scale (surface);
+      GDK_DEBUG (VULKAN, "GTK selecting swapchain size as %ux%u",
+                 (guint) size.width, (guint) size.height);
+    }
+  else if (capabilities.currentExtent.width == size.width &&
+           capabilities.currentExtent.height == size.height)
+    {
+      GDK_DEBUG (VULKAN, "Vulkan and GTK agree on size as %ux%u",
+                 (guint) size.width, (guint) size.height);
+    }
+  else
+    {
+      GDK_DEBUG (VULKAN, "Vulkan %ux%u and GTK %ux%u disagree on size, using GTK's",
+                 (guint) capabilities.currentExtent.width, (guint) capabilities.currentExtent.height,
+                 (guint) size.width, (guint) size.height);
+    }
 
-      capabilities.currentExtent.width = MAX (1, (int) ceil (gdk_surface_get_width (surface) * scale));
-      capabilities.currentExtent.height = MAX (1, (int) ceil (gdk_surface_get_height (surface) * scale));
+  if (capabilities.minImageExtent.width > size.width ||
+      capabilities.minImageExtent.height > size.height ||
+      capabilities.maxImageExtent.width < size.width ||
+      capabilities.maxImageExtent.height < size.height)
+    {
+      /* Should this be a g_warning()? */
+      GDK_DEBUG (VULKAN, "Clamping size %ux%u to fit into min %ux%u, max %ux%u",
+                 (guint) size.width, (guint) size.height,
+                 (guint) capabilities.minImageExtent.width, (guint) capabilities.minImageExtent.height,
+                 (guint) capabilities.maxImageExtent.width, (guint) capabilities.maxImageExtent.height);
+      size.width = CLAMP (size.width, capabilities.minImageExtent.width, capabilities.maxImageExtent.width);
+      size.height = CLAMP (size.height, capabilities.minImageExtent.height, capabilities.maxImageExtent.height);
     }
 
   res = GDK_VK_CHECK (vkCreateSwapchainKHR, device,
@@ -481,7 +521,7 @@ gdk_vulkan_context_check_swapchain (GdkVulkanContext  *context,
                                                                         capabilities.maxImageCount ? capabilities.maxImageCount : G_MAXUINT32),
                                                 .imageFormat = priv->formats[priv->current_depth].vk_format.format,
                                                 .imageColorSpace = priv->formats[priv->current_depth].vk_format.colorSpace,
-                                                .imageExtent = capabilities.currentExtent,
+                                                .imageExtent = size,
                                                 .imageArrayLayers = 1,
                                                 .imageUsage = VK_IMAGE_USAGE_COLOR_ATTACHMENT_BIT,
                                                 .imageSharingMode = VK_SHARING_MODE_EXCLUSIVE,
@@ -686,7 +726,37 @@ gdk_vulkan_context_begin_frame (GdkDrawContext  *draw_context,
         {
           GError *error = NULL;
 
-          GDK_DEBUG (VULKAN, "Recreating the swapchain");
+          if (acquire_result == VK_SUBOPTIMAL_KHR)
+            {
+              const VkPipelineStageFlags mask = VK_PIPELINE_STAGE_BOTTOM_OF_PIPE_BIT;
+
+              vkQueueSubmit (gdk_vulkan_context_get_queue (context),
+                             1,
+                             &(VkSubmitInfo) {
+                               .sType = VK_STRUCTURE_TYPE_SUBMIT_INFO,
+                               .waitSemaphoreCount = 1,
+                               .pWaitSemaphores = &priv->draw_semaphore,
+                               .pWaitDstStageMask = &mask,
+                             },
+                             VK_NULL_HANDLE);
+              vkQueueWaitIdle (gdk_vulkan_context_get_queue (context));
+
+              if (gdk_vulkan_context_has_feature (context, GDK_VULKAN_FEATURE_SWAPCHAIN_MAINTENANCE))
+                {
+                  PFN_vkReleaseSwapchainImagesEXT vkReleaseSwapchainImagesEXT;
+
+                  vkReleaseSwapchainImagesEXT = (PFN_vkReleaseSwapchainImagesEXT) vkGetDeviceProcAddr (gdk_vulkan_context_get_device (context), "vkReleaseSwapchainImagesEXT");
+
+                  vkReleaseSwapchainImagesEXT (gdk_vulkan_context_get_device (context),
+                                            &(VkReleaseSwapchainImagesInfoEXT) {
+                                              .sType = VK_STRUCTURE_TYPE_RELEASE_SWAPCHAIN_IMAGES_INFO_EXT,
+                                              .pNext = NULL,
+                                              .swapchain = priv->swapchain,
+                                              .imageIndexCount = 1,
+                                              .pImageIndices = &priv->draw_index,
+                                            });
+                }
+            }
 
           if (gdk_vulkan_context_check_swapchain (context, &error))
             continue;
@@ -788,6 +858,20 @@ gdk_vulkan_context_surface_resized (GdkDrawContext *draw_context)
     }
 }
 
+static void
+gdk_vulkan_context_get_default_image_size (GdkVulkanContext *context,
+                                           uint32_t         *width,
+                                           uint32_t         *height)
+{
+  GdkSurface *surface = gdk_draw_context_get_surface (GDK_DRAW_CONTEXT (context));
+  double scale;
+
+  scale = gdk_surface_get_scale (surface);
+
+  *width = MAX (1, (uint32_t) ceil (gdk_surface_get_width (surface) * scale));
+  *height = MAX (1, (uint32_t) ceil (gdk_surface_get_height (surface) * scale));
+}
+
 static void
 gdk_vulkan_context_class_init (GdkVulkanContextClass *klass)
 {
@@ -800,6 +884,8 @@ gdk_vulkan_context_class_init (GdkVulkanContextClass *klass)
   draw_context_class->end_frame = gdk_vulkan_context_end_frame;
   draw_context_class->surface_resized = gdk_vulkan_context_surface_resized;
 
+  klass->get_image_size = gdk_vulkan_context_get_default_image_size;
+
   /**
    * GdkVulkanContext::images-updated:
    * @context: the object on which the signal is emitted
@@ -1430,8 +1516,8 @@ gdk_display_create_vulkan_device (GdkDisplay  *display,
 
   skip_features = gdk_parse_debug_var ("GDK_VULKAN_DISABLE",
       "GDK_VULKAN_DISABLE can be set to a list of Vulkan features to disable.\n",
-      gsk_vulkan_feature_keys,
-      G_N_ELEMENTS (gsk_vulkan_feature_keys));
+      gdk_vulkan_feature_keys,
+      G_N_ELEMENTS (gdk_vulkan_feature_keys));
   if (skip_features & GDK_VULKAN_FEATURE_YCBCR)
     skip_features |= GDK_VULKAN_FEATURE_DMABUF;
 
@@ -1606,13 +1692,13 @@ gdk_display_create_vulkan_device (GdkDisplay  *display,
               display->vulkan_features = features;
 
               GDK_DISPLAY_DEBUG (display, VULKAN, "Enabled features (use GDK_VULKAN_DISABLE env var to disable):");
-              for (i = 0; i < G_N_ELEMENTS (gsk_vulkan_feature_keys); i++)
+              for (i = 0; i < G_N_ELEMENTS (gdk_vulkan_feature_keys); i++)
                 {
                   GDK_DISPLAY_DEBUG (display, VULKAN, "    %s: %s",
-                                     gsk_vulkan_feature_keys[i].key,
-                                     (features & gsk_vulkan_feature_keys[i].value) ? "YES" :
-                                     ((skip_features & gsk_vulkan_feature_keys[i].value) ? "disabled via env var" :
-                                      (((device_features & gsk_vulkan_feature_keys[i].value) == 0) ? "not supported" :
+                                     gdk_vulkan_feature_keys[i].key,
+                                     (features & gdk_vulkan_feature_keys[i].value) ? "✓" :
+                                     ((skip_features & gdk_vulkan_feature_keys[i].value) ? "disabled via env var" :
+                                      (((device_features & gdk_vulkan_feature_keys[i].value) == 0) ? "✗" :
                                        "Hum, what? This should not happen.")));
                 }
 
@@ -1639,9 +1725,9 @@ gdk_vulkan_debug_report (VkDebugReportFlagsEXT      flags,
                          void*                      pUserData)
 {
   if (flags & VK_DEBUG_REPORT_ERROR_BIT_EXT)
-    g_critical ("Vulkan: %s: %s", pLayerPrefix, pMessage);
+    g_warning ("Vulkan: %s: %s", pLayerPrefix, pMessage);
   else if (flags & VK_DEBUG_REPORT_WARNING_BIT_EXT)
-    g_critical ("Vulkan: %s: %s", pLayerPrefix, pMessage);
+    g_warning ("Vulkan: %s: %s", pLayerPrefix, pMessage);
   else if (flags & VK_DEBUG_REPORT_PERFORMANCE_WARNING_BIT_EXT)
     g_warning ("Vulkan: %s: %s", pLayerPrefix, pMessage);
   else if (flags & VK_DEBUG_REPORT_DEBUG_BIT_EXT)
@@ -1888,8 +1974,6 @@ gdk_display_unref_vulkan (GdkDisplay *display)
   display->vk_instance = VK_NULL_HANDLE;
 }
 
-#ifdef HAVE_DMABUF
-
 /* Hack. We don't include gsk/gsk.h here to avoid a build order problem
  * with the generated header gskenumtypes.h, so we need to hack around
  * a bit to access the gsk api we need.
@@ -1902,10 +1986,10 @@ extern gboolean        gsk_renderer_realize_for_display         (GskRenderer  *r
                                                                  GdkDisplay   *display,
                                                                  GError      **error);
 
-GdkDmabufDownloader *
-gdk_vulkan_get_dmabuf_downloader (GdkDisplay              *display,
-                                  GdkDmabufFormatsBuilder *builder)
+void
+gdk_vulkan_init_dmabuf (GdkDisplay *display)
 {
+#ifdef HAVE_DMABUF
   GdkDmabufFormatsBuilder *vulkan_builder;
   GskRenderer *renderer;
   VkDrmFormatModifierPropertiesEXT modifier_list[100];
@@ -1923,13 +2007,15 @@ gdk_vulkan_get_dmabuf_downloader (GdkDisplay              *display,
   GError *error = NULL;
   gsize i, j;
 
-  g_assert (display->vk_dmabuf_formats == NULL);
+  if (display->vk_dmabuf_formats != NULL)
+    return;
 
-  if (!gdk_display_init_vulkan (display, NULL))
-    return NULL;
-
-  if ((display->vulkan_features & GDK_VULKAN_FEATURE_DMABUF) == 0)
-    return NULL;
+  if (!gdk_has_feature (GDK_FEATURE_DMABUF) ||
+      !gdk_display_init_vulkan (display, NULL) ||
+      ((display->vulkan_features & GDK_VULKAN_FEATURE_DMABUF) == 0))
+    {
+      return;
+    }
 
   vulkan_builder = gdk_dmabuf_formats_builder_new ();
 
@@ -1963,23 +2049,20 @@ gdk_vulkan_get_dmabuf_downloader (GdkDisplay              *display,
 
   display->vk_dmabuf_formats = gdk_dmabuf_formats_builder_free_to_formats (vulkan_builder);
 
-  gdk_dmabuf_formats_builder_add_formats (builder, display->vk_dmabuf_formats);
-
   renderer = gsk_vulkan_renderer_new ();
 
   if (!gsk_renderer_realize_for_display (renderer, display, &error))
     {
-      g_warning ("Failed to realize GL renderer: %s", error->message);
+      g_warning ("Failed to realize Vulkan renderer: %s", error->message);
       g_error_free (error);
       g_object_unref (renderer);
-
-      return NULL;
     }
-
-  return GDK_DMABUF_DOWNLOADER (renderer);
-}
-
+  else
+    {
+      display->vk_downloader = GDK_DMABUF_DOWNLOADER (renderer);
+    }
 #endif
+}
 
 VkShaderModule
 gdk_display_get_vk_shader_module (GdkDisplay *self,
