@@ -19,13 +19,11 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GDK_WAYLAND_GL_CONTEXT__
-#define __GDK_WAYLAND_GL_CONTEXT__
+#pragma once
 
 #include "gdkglcontextprivate.h"
 #include "gdkdisplayprivate.h"
 #include "gdksurface.h"
-#include "gdkinternals.h"
 
 #include <epoxy/egl.h>
 
@@ -34,8 +32,6 @@ G_BEGIN_DECLS
 struct _GdkWaylandGLContext
 {
   GdkGLContext parent_instance;
-
-  EGLContext egl_context;
 };
 
 struct _GdkWaylandGLContextClass
@@ -48,4 +44,3 @@ GdkGLContext *  gdk_wayland_display_init_gl                         (GdkDisplay
 
 G_END_DECLS
 
-#endif /* __GDK_WAYLAND_GL_CONTEXT__ */
