@@ -80,7 +80,7 @@ void
 gsk_gpu_device_maybe_gc (GskGpuDevice *self)
 {
   GskGpuDevicePrivate *priv = gsk_gpu_device_get_instance_private (self);
-  gsize dead_texture_pixels;
+  gsize dead_texture_pixels, dead_textures;
 
   if (priv->cache_timeout < 0)
     return;
@@ -88,11 +88,13 @@ gsk_gpu_device_maybe_gc (GskGpuDevice *self)
   if (priv->cache == NULL)
     return;
 
+  dead_textures = gsk_gpu_cache_get_dead_textures (priv->cache);
   dead_texture_pixels = gsk_gpu_cache_get_dead_texture_pixels (priv->cache);
 
-  if (priv->cache_timeout == 0 || dead_texture_pixels > 1000000)
+  if (priv->cache_timeout == 0 || dead_textures > 50 || dead_texture_pixels > 1000 * 1000)
     {
-      GSK_DEBUG (CACHE, "Pre-frame GC (%" G_GSIZE_FORMAT " dead pixels)", dead_texture_pixels);
+      GSK_DEBUG (CACHE, "Pre-frame GC (%" G_GSIZE_FORMAT " dead textures, %" G_GSIZE_FORMAT " dead pixels)",
+                 dead_textures, dead_texture_pixels);
       gsk_gpu_device_gc (self, g_get_monotonic_time ());
     }
 }
