@@ -9,7 +9,7 @@ typedef struct {
   char *description;
   gint64 value;
   gint64 n_samples;
-  gboolean can_reset : 1;
+  unsigned int can_reset : 1;
 } NamedCounter;
 
 typedef struct {
@@ -21,9 +21,9 @@ typedef struct {
   gint64 max_value;
   gint64 avg_value;
   gint64 n_samples;
-  gboolean in_flight : 1;
-  gboolean can_reset : 1;
-  gboolean invert : 1;
+  unsigned int in_flight : 1;
+  unsigned int can_reset : 1;
+  unsigned int invert : 1;
 } NamedTimer;
 
 typedef struct {
@@ -53,8 +53,7 @@ named_counter_free (gpointer data)
     return;
 
   g_free (counter->description);
-
-  g_slice_free (NamedCounter, counter);
+  g_free (counter);
 }
 
 static void
@@ -66,8 +65,7 @@ named_timer_free (gpointer data)
     return;
 
   g_free (timer->description);
-
-  g_slice_free (NamedTimer, timer);
+  g_free (timer);
 }
 
 static void
@@ -109,7 +107,7 @@ named_counter_new (GQuark      id,
                    const char *description,
                    gboolean    can_reset)
 {
-  NamedCounter *res = g_slice_new0 (NamedCounter);
+  NamedCounter *res = g_new0 (NamedCounter, 1);
 
   res->id = id;
   res->description = g_strdup (description);
@@ -156,7 +154,7 @@ named_timer_new (GQuark      id,
                  gboolean    invert,
                  gboolean    can_reset)
 {
-  NamedTimer *res = g_slice_new0 (NamedTimer);
+  NamedTimer *res = g_new0 (NamedTimer, 1);
 
   res->id = id;
   res->description = g_strdup (description);
@@ -262,7 +260,7 @@ gsk_profiler_timer_begin (GskProfiler *profiler,
     return;
 
   timer->in_flight = TRUE;
-  timer->start_time = g_get_monotonic_time () * 1000;
+  timer->start_time = g_get_monotonic_time ();
 }
 
 gint64
@@ -289,7 +287,7 @@ gsk_profiler_timer_end (GskProfiler *profiler,
       return 0;
     }
 
-  diff = (g_get_monotonic_time () * 1000) - timer->start_time;
+  diff = g_get_monotonic_time () - timer->start_time;
 
   timer->in_flight = FALSE;
   timer->value += diff; 
@@ -360,7 +358,7 @@ gsk_profiler_timer_get (GskProfiler *profiler,
     }
 
   if (timer->invert)
-    return (gint64) (1000000000.0 / (double) timer->value);
+    return (gint64) (1000000.0 / (double) timer->value);
 
   return timer->value;
 }
@@ -437,7 +435,7 @@ gsk_profiler_push_samples (GskProfiler *profiler)
       s->id = timer->id;
 
       if (timer->invert)
-        s->value = (gint64) (1000000000.0 / (double) timer->value);
+        s->value = (gint64) (1000000.0 / (double) timer->value);
       else
         s->value = timer->value;
     }
@@ -506,20 +504,19 @@ gsk_profiler_append_timers (GskProfiler *profiler,
     {
       NamedTimer *timer = value_p;
       const char *unit = timer->invert ? "" : "usec";
-      double scale = timer->invert ? 1.0 : 1000.0;
 
       g_string_append_printf (buffer, "%s (%s): %.2f",
                               timer->description,
                               unit,
-                              (double) timer->value / scale);
+                              (double) timer->value);
 
       if (timer->n_samples > 1)
         {
           timer->avg_value = timer->avg_value / timer->n_samples;
           g_string_append_printf (buffer, " Min: %.2f Avg: %.2f Max: %.2f (%" G_GINT64_FORMAT " samples)",
-                                  (double) timer->min_value / scale,
-                                  (double) timer->avg_value / scale,
-                                  (double) timer->max_value / scale,
+                                  (double) timer->min_value,
+                                  (double) timer->avg_value,
+                                  (double) timer->max_value,
                                   timer->n_samples);
         }
 
