@@ -18,16 +18,20 @@
  */
 
 /**
- * SECTION:gtkconstraintguide
- * @Title: GtkConstraintGuide
- * @Short_description: An invisible constraint target
+ * GtkConstraintGuide:
  *
- * A #GtkConstraintGuide is an invisible layout element that can be
- * used by widgets inside a #GtkConstraintLayout as a source or a target
- * of a #GtkConstraint. Guides can be used like guidelines or as
- * flexible space.
+ * A `GtkConstraintGuide` is an invisible layout element in a
+ * `GtkConstraintLayout`.
  *
- * Unlike a #GtkWidget, a #GtkConstraintGuide will not be drawn.
+ * The `GtkConstraintLayout` treats guides like widgets. They
+ * can be used as the source or target of a `GtkConstraint`.
+ *
+ * Guides have a minimum, maximum and natural size. Depending
+ * on the constraints that are applied, they can act like a
+ * guideline that widgets can be aligned to, or like *flexible
+ * space*.
+ *
+ * Unlike a `GtkWidget`, a `GtkConstraintGuide` will not be drawn.
  */
 
 #include "config.h"
@@ -40,7 +44,6 @@
 #include "gtkconstraintsolverprivate.h"
 
 #include "gtkdebug.h"
-#include "gtkintl.h"
 #include "gtkprivate.h"
 
 
@@ -347,95 +350,86 @@ gtk_constraint_guide_class_init (GtkConstraintGuideClass *class)
    * The minimum width of the guide.
    */
   guide_props[PROP_MIN_WIDTH] =
-      g_param_spec_int ("min-width",
-                        "Minimum width",
-                        "Minimum width",
+      g_param_spec_int ("min-width", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:min-height:
    *
    * The minimum height of the guide.
    */
   guide_props[PROP_MIN_HEIGHT] =
-      g_param_spec_int ("min-height",
-                        "Minimum height",
-                        "Minimum height",
+      g_param_spec_int ("min-height", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:nat-width:
    *
    * The preferred, or natural, width of the guide.
    */
   guide_props[PROP_NAT_WIDTH] =
-      g_param_spec_int ("nat-width",
-                        "Natural width",
-                        "Natural width",
+      g_param_spec_int ("nat-width", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:nat-height:
    *
    * The preferred, or natural, height of the guide.
    */
   guide_props[PROP_NAT_HEIGHT] =
-      g_param_spec_int ("nat-height",
-                        "Natural height",
-                        "Natural height",
+      g_param_spec_int ("nat-height", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:max-width:
    *
    * The maximum width of the guide.
    */
   guide_props[PROP_MAX_WIDTH] =
-      g_param_spec_int ("max-width",
-                        "Maximum width",
-                        "Maximum width",
+      g_param_spec_int ("max-width", NULL, NULL,
                         0, G_MAXINT, G_MAXINT,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:max-height:
    *
    * The maximum height of the guide.
    */
   guide_props[PROP_MAX_HEIGHT] =
-      g_param_spec_int ("max-height",
-                        "Maximum height",
-                        "Maximum height",
+      g_param_spec_int ("max-height", NULL, NULL,
                         0, G_MAXINT, G_MAXINT,
                         G_PARAM_READWRITE|
                         G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:strength:
    *
-   * The #GtkConstraintStrength to be used for the constraint on
+   * The `GtkConstraintStrength` to be used for the constraint on
    * the natural size of the guide.
    */
   guide_props[PROP_STRENGTH] =
-      g_param_spec_enum ("strength",
-                         "Strength",
-                         "The strength to use for natural size",
+      g_param_spec_enum ("strength", NULL, NULL,
                          GTK_TYPE_CONSTRAINT_STRENGTH,
                          GTK_CONSTRAINT_STRENGTH_MEDIUM,
                          G_PARAM_READWRITE|
                          G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * GtkConstraintGuide:name:
    *
-   * A name that identifies the #GtkConstraintGuide, for debugging.
+   * A name that identifies the `GtkConstraintGuide`, for debugging.
    */
   guide_props[PROP_NAME] =
-      g_param_spec_string ("name",
-                           "Name",
-                           "A name to use in debug message",
+      g_param_spec_string ("name", NULL, NULL,
                            NULL,
                            G_PARAM_READWRITE);
 
@@ -445,9 +439,9 @@ gtk_constraint_guide_class_init (GtkConstraintGuideClass *class)
 /**
  * gtk_constraint_guide_new:
  *
- * Creates a new #GtkConstraintGuide object.
+ * Creates a new `GtkConstraintGuide` object.
  *
- * Return: a new #GtkConstraintGuide object.
+ * Return: a new `GtkConstraintGuide` object.
  */
 GtkConstraintGuide *
 gtk_constraint_guide_new (void)
@@ -457,13 +451,13 @@ gtk_constraint_guide_new (void)
 
 /**
  * gtk_constraint_guide_set_min_size:
- * @guide: a #GtkConstraintGuide object
+ * @guide: a `GtkConstraintGuide` object
  * @width: the new minimum width, or -1 to not change it
  * @height: the new minimum height, or -1 to not change it
  *
  * Sets the minimum size of @guide.
  *
- * If @guide is attached to a #GtkConstraintLayout,
+ * If @guide is attached to a `GtkConstraintLayout`,
  * the constraints will be updated to reflect the new size.
  */
 void
@@ -488,11 +482,9 @@ gtk_constraint_guide_set_min_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_get_min_size:
- * @guide: a #GtkConstraintGuide object
- * @width: (allow-none): return location for the minimum width,
- *     or %NULL
- * @height: (allow-none): return location for the minimum height,
- *     or %NULL
+ * @guide: a `GtkConstraintGuide` object
+ * @width: (out) (optional): return location for the minimum width
+ * @height: (out) (optional): return location for the minimum height
  *
  * Gets the minimum size of @guide.
  */
@@ -511,13 +503,13 @@ gtk_constraint_guide_get_min_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_set_nat_size:
- * @guide: a #GtkConstraintGuide object
+ * @guide: a `GtkConstraintGuide` object
  * @width: the new natural width, or -1 to not change it
  * @height: the new natural height, or -1 to not change it
  *
  * Sets the natural size of @guide.
  *
- * If @guide is attached to a #GtkConstraintLayout,
+ * If @guide is attached to a `GtkConstraintLayout`,
  * the constraints will be updated to reflect the new size.
  */
 void
@@ -542,11 +534,9 @@ gtk_constraint_guide_set_nat_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_get_nat_size:
- * @guide: a #GtkConstraintGuide object
- * @width: (allow-none): return location for the natural width,
- *     or %NULL
- * @height: (allow-none): return location for the natural height,
- *     or %NULL
+ * @guide: a `GtkConstraintGuide` object
+ * @width: (out) (optional): return location for the natural width
+ * @height: (out) (optional): return location for the natural height
  *
  * Gets the natural size of @guide.
  */
@@ -565,13 +555,13 @@ gtk_constraint_guide_get_nat_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_set_max_size:
- * @guide: a #GtkConstraintGuide object
+ * @guide: a `GtkConstraintGuide` object
  * @width: the new maximum width, or -1 to not change it
  * @height: the new maximum height, or -1 to not change it
  *
  * Sets the maximum size of @guide.
  *
- * If @guide is attached to a #GtkConstraintLayout,
+ * If @guide is attached to a `GtkConstraintLayout`,
  * the constraints will be updated to reflect the new size.
  */
 void
@@ -596,11 +586,9 @@ gtk_constraint_guide_set_max_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_get_max_size:
- * @guide: a #GtkConstraintGuide object
- * @width: (allow-none): return location for the maximum width,
- *     or %NULL
- * @height: (allow-none): return location for the maximum height,
- *     or %NULL
+ * @guide: a `GtkConstraintGuide` object
+ * @width: (out) (optional): return location for the maximum width
+ * @height: (out) (optional): return location for the maximum height
  *
  * Gets the maximum size of @guide.
  */
@@ -619,7 +607,7 @@ gtk_constraint_guide_get_max_size (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_get_name:
- * @guide: a #GtkConstraintGuide
+ * @guide: a `GtkConstraintGuide`
  *
  * Retrieves the name set using gtk_constraint_guide_set_name().
  *
@@ -635,10 +623,10 @@ gtk_constraint_guide_get_name (GtkConstraintGuide *guide)
 
 /**
  * gtk_constraint_guide_set_name:
- * @guide: a #GtkConstraintGuide
+ * @guide: a `GtkConstraintGuide`
  * @name: (nullable): a name for the @guide
  *
- * Sets a name for the given #GtkConstraintGuide.
+ * Sets a name for the given `GtkConstraintGuide`.
  *
  * The name is useful for debugging purposes.
  */
@@ -655,7 +643,7 @@ gtk_constraint_guide_set_name (GtkConstraintGuide *guide,
 
 /**
  * gtk_constraint_guide_get_strength:
- * @guide: a #GtkConstraintGuide
+ * @guide: a `GtkConstraintGuide`
  *
  * Retrieves the strength set using gtk_constraint_guide_set_strength().
  *
@@ -672,11 +660,11 @@ gtk_constraint_guide_get_strength (GtkConstraintGuide *guide)
 
 /**
  * gtk_constraint_guide_set_strength:
- * @guide: a #GtkConstraintGuide
+ * @guide: a `GtkConstraintGuide`
  * @strength: the strength of the constraint
  *
  * Sets the strength of the constraint on the natural size of the
- * given #GtkConstraintGuide.
+ * given `GtkConstraintGuide`.
  */
 void
 gtk_constraint_guide_set_strength (GtkConstraintGuide    *guide,
