@@ -215,7 +215,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkFileChooserNative, gtk_file_chooser_native, GTK_TYPE
 
 
 /**
- * gtk_file_chooser_native_get_accept_label: (attributes org.gtk.Method.get_property=accept-label)
+ * gtk_file_chooser_native_get_accept_label:
  * @self: a `GtkFileChooserNative`
  *
  * Retrieves the custom label text for the accept button.
@@ -233,7 +233,7 @@ gtk_file_chooser_native_get_accept_label (GtkFileChooserNative *self)
 }
 
 /**
- * gtk_file_chooser_native_set_accept_label: (attributes org.gtk.Method.set_property=accept-label)
+ * gtk_file_chooser_native_set_accept_label:
  * @self: a `GtkFileChooserNative`
  * @accept_label: (nullable): custom label
  *
@@ -261,7 +261,7 @@ gtk_file_chooser_native_set_accept_label (GtkFileChooserNative *self,
 }
 
 /**
- * gtk_file_chooser_native_get_cancel_label: (attributes org.gtk.Method.get_property=cancel-label)
+ * gtk_file_chooser_native_get_cancel_label:
  * @self: a `GtkFileChooserNative`
  *
  * Retrieves the custom label text for the cancel button.
@@ -279,7 +279,7 @@ gtk_file_chooser_native_get_cancel_label (GtkFileChooserNative *self)
 }
 
 /**
- * gtk_file_chooser_native_set_cancel_label: (attributes org.gtk.Method.set_property=cancel-label)
+ * gtk_file_chooser_native_set_cancel_label:
  * @self: a `GtkFileChooserNative`
  * @cancel_label: (nullable): custom label
  *
@@ -561,6 +561,13 @@ gtk_file_chooser_native_new (const char           *title,
   return result;
 }
 
+void
+gtk_file_chooser_native_set_use_portal (GtkFileChooserNative *self,
+                                        gboolean              use_portal)
+{
+  self->use_portal = use_portal;
+}
+
 static void
 dialog_response_cb (GtkDialog *dialog,
                     int response_id,
@@ -569,7 +576,7 @@ dialog_response_cb (GtkDialog *dialog,
   GtkFileChooserNative *self = data;
 
   g_signal_handlers_disconnect_by_func (self->dialog, dialog_response_cb, self);
-  gtk_widget_hide (self->dialog);
+  gtk_widget_set_visible (self->dialog, FALSE);
 
   _gtk_native_dialog_emit_response (GTK_NATIVE_DIALOG (self), response_id);
 }
@@ -615,7 +622,7 @@ static void
 hide_dialog (GtkFileChooserNative *self)
 {
   g_signal_handlers_disconnect_by_func (self->dialog, dialog_response_cb, self);
-  gtk_widget_hide (self->dialog);
+  gtk_widget_set_visible (self->dialog, FALSE);
 }
 
 static gboolean
@@ -779,7 +786,7 @@ gtk_file_chooser_native_class_init (GtkFileChooserNativeClass *class)
   _gtk_file_chooser_install_properties (gobject_class);
 
   /**
-   * GtkFileChooserNative:accept-label: (attributes org.gtk.Property.get=gtk_file_chooser_native_get_accept_label org.gtk.Property.set=gtk_file_chooser_native_set_accept_label)
+   * GtkFileChooserNative:accept-label:
    *
    * The text used for the label on the accept button in the dialog, or
    * %NULL to use the default text.
@@ -790,7 +797,7 @@ gtk_file_chooser_native_class_init (GtkFileChooserNativeClass *class)
                            GTK_PARAM_READWRITE);
 
   /**
-   * GtkFileChooserNative:cancel-label: (attributes org.gtk.Property.get=gtk_file_chooser_native_get_cancel_label org.gtk.Property.set=gtk_file_chooser_native_set_cancel_label)
+   * GtkFileChooserNative:cancel-label:
    *
    * The text used for the label on the cancel button in the dialog, or
    * %NULL to use the default text.
