@@ -32,7 +32,7 @@
 #include "gtkwidgetprivate.h"
 #include "gtktypebuiltins.h"
 
-
+static void     activated      (GtkFontDialogButton *self);
 static void     button_clicked (GtkFontDialogButton *self);
 static void     update_button_sensitivity
                                (GtkFontDialogButton *self);
@@ -100,8 +100,17 @@ enum
   NUM_PROPERTIES
 };
 
+/* Signals */
+enum
+{
+  SIGNAL_ACTIVATE = 1,
+  NUM_SIGNALS
+};
+
 static GParamSpec *properties[NUM_PROPERTIES];
 
+static unsigned int font_dialog_button_signals[NUM_SIGNALS] = { 0 };
+
 G_DEFINE_TYPE (GtkFontDialogButton, gtk_font_dialog_button, GTK_TYPE_WIDGET)
 
 static void
@@ -110,6 +119,8 @@ gtk_font_dialog_button_init (GtkFontDialogButton *self)
   GtkWidget *box;
   PangoFontDescription *font_desc;
 
+  g_signal_connect_swapped (self, "activate", G_CALLBACK (activated), self);
+
   self->button = gtk_button_new ();
   g_signal_connect_swapped (self->button, "clicked", G_CALLBACK (button_clicked), self);
   self->font_label = gtk_label_new (_("Font"));
@@ -283,7 +294,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
   widget_class->unroot = gtk_font_dialog_button_unroot;
 
   /**
-   * GtkFontDialogButton:dialog: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_dialog org.gtk.Property.set=gtk_font_dialog_button_set_dialog)
+   * GtkFontDialogButton:dialog:
    *
    * The `GtkFontDialog` that contains parameters for
    * the font chooser dialog.
@@ -296,7 +307,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                            G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:level: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_level org.gtk.Property.set=gtk_font_dialog_button_set_level)
+   * GtkFontDialogButton:level:
    *
    * The level of detail for the font chooser dialog.
    */
@@ -307,7 +318,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                          GTK_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:font-desc: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_font_desc org.gtk.Property.set=gtk_font_dialog_button_set_font_desc)
+   * GtkFontDialogButton:font-desc:
    *
    * The selected font.
    *
@@ -326,7 +337,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                           G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:font-features: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_font_features org.gtk.Property.set=gtk_font_dialog_button_set_font_features)
+   * GtkFontDialogButton:font-features:
    *
    * The selected font features.
    *
@@ -344,7 +355,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                            G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:language: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_language org.gtk.Property.set=gtk_font_dialog_button_set_language)
+   * GtkFontDialogButton:language:
    *
    * The selected language for font features.
    *
@@ -362,7 +373,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                           G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:use-font: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_use_font org.gtk.Property.set=gtk_font_dialog_button_set_use_font)
+   * GtkFontDialogButton:use-font:
    *
    * Whether the buttons label will be drawn in the selected font.
    */
@@ -372,7 +383,7 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
                             GTK_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkFontDialogButton:use-size: (attributes org.gtk.Property.get=gtk_font_dialog_button_get_use_size org.gtk.Property.set=gtk_font_dialog_button_set_use_size)
+   * GtkFontDialogButton:use-size:
    *
    * Whether the buttons label will use the selected font size.
    */
@@ -383,6 +394,27 @@ gtk_font_dialog_button_class_init (GtkFontDialogButtonClass *class)
 
   g_object_class_install_properties (object_class, NUM_PROPERTIES, properties);
 
+  /**
+   * GtkFontDialogButton::activate:
+   * @widget: The object which received the signal
+   *
+   * Emitted when the font dialog button is activated.
+   *
+   * The `::activate` signal on `GtkFontDialogButton` is an action signal
+   * and emitting it causes the button to pop up its dialog.
+   *
+   * Since: 4.14
+   */
+  font_dialog_button_signals[SIGNAL_ACTIVATE] =
+    g_signal_new (I_ ("activate"),
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
+                  0,
+                  NULL, NULL,
+                  NULL,
+                  G_TYPE_NONE, 0);
+
+  gtk_widget_class_set_activate_signal (widget_class, font_dialog_button_signals[SIGNAL_ACTIVATE]);
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
   gtk_widget_class_set_css_name (widget_class, "fontbutton");
   gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_GROUP);
@@ -499,6 +531,12 @@ font_and_features_chosen (GObject      *source,
   update_button_sensitivity (self);
 }
 
+static void
+activated (GtkFontDialogButton *self)
+{
+  gtk_widget_activate (self->button);
+}
+
 static void
 button_clicked (GtkFontDialogButton *self)
 {
