@@ -227,7 +227,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_BOOLEAN_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_BOOLEAN_SORT_KEYS_CLASS,
                                   sizeof (char),
-                                  sizeof (char));
+                                  G_ALIGNOF (char));
       break;
 
     case G_TYPE_CHAR:
@@ -236,7 +236,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_CHAR_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_CHAR_SORT_KEYS_CLASS,
                                   sizeof (char),
-                                  sizeof (char));
+                                  G_ALIGNOF (char));
       break;
 
     case G_TYPE_UCHAR:
@@ -245,7 +245,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_UCHAR_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_UCHAR_SORT_KEYS_CLASS,
                                   sizeof (guchar),
-                                  sizeof (guchar));
+                                  G_ALIGNOF (guchar));
       break;
 
     case G_TYPE_INT:
@@ -254,7 +254,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_INT_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_INT_SORT_KEYS_CLASS,
                                   sizeof (int),
-                                  sizeof (int));
+                                  G_ALIGNOF (int));
       break;
 
     case G_TYPE_UINT:
@@ -263,7 +263,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_UINT_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_UINT_SORT_KEYS_CLASS,
                                   sizeof (guint),
-                                  sizeof (guint));
+                                  G_ALIGNOF (guint));
       break;
 
     case G_TYPE_FLOAT:
@@ -272,7 +272,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_FLOAT_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_FLOAT_SORT_KEYS_CLASS,
                                   sizeof (float),
-                                  sizeof (float));
+                                  G_ALIGNOF (float));
       break;
 
     case G_TYPE_DOUBLE:
@@ -281,7 +281,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_DOUBLE_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_DOUBLE_SORT_KEYS_CLASS,
                                   sizeof (double),
-                                  sizeof (double));
+                                  G_ALIGNOF (double));
       break;
 
     case G_TYPE_LONG:
@@ -290,7 +290,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_LONG_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_LONG_SORT_KEYS_CLASS,
                                   sizeof (long),
-                                  sizeof (long));
+                                  G_ALIGNOF (long));
       break;
 
     case G_TYPE_ULONG:
@@ -299,7 +299,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_ULONG_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_ULONG_SORT_KEYS_CLASS,
                                   sizeof (gulong),
-                                  sizeof (gulong));
+                                  G_ALIGNOF (gulong));
       break;
 
     case G_TYPE_INT64:
@@ -308,7 +308,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_INT64_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_INT64_SORT_KEYS_CLASS,
                                   sizeof (gint64),
-                                  sizeof (gint64));
+                                  G_ALIGNOF (gint64));
       break;
 
     case G_TYPE_UINT64:
@@ -317,7 +317,7 @@ gtk_numeric_sort_keys_new (GtkNumericSorter *self)
                                                       ? &GTK_ASCENDING_UINT64_SORT_KEYS_CLASS
                                                       : &GTK_DESCENDING_UINT64_SORT_KEYS_CLASS,
                                   sizeof (guint64),
-                                  sizeof (guint64));
+                                  G_ALIGNOF (guint64));
       break;
 
     default:
@@ -538,7 +538,7 @@ gtk_numeric_sorter_class_init (GtkNumericSorterClass *class)
   object_class->dispose = gtk_numeric_sorter_dispose;
 
   /**
-   * GtkNumericSorter:expression: (type GtkExpression) (attributes org.gtk.Property.get=gtk_numeric_sorter_get_expression org.gtk.Property.set=gtk_numeric_sorter_set_expression)
+   * GtkNumericSorter:expression: (type GtkExpression)
    *
    * The expression to evaluate on items to get a number to compare with.
    */
@@ -547,7 +547,7 @@ gtk_numeric_sorter_class_init (GtkNumericSorterClass *class)
                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkNumericSorter:sort-order: (attributes org.gtk.Property.get=gtk_numeric_sorter_get_sort_order org.gtk.Property.set=gtk_numeric_sorter_set_sort_order)
+   * GtkNumericSorter:sort-order:
    *
    * Whether the sorter will sort smaller numbers first.
    */
@@ -597,7 +597,7 @@ gtk_numeric_sorter_new (GtkExpression *expression)
 }
 
 /**
- * gtk_numeric_sorter_get_expression: (attributes org.gtk.Method.get_property=expression)
+ * gtk_numeric_sorter_get_expression:
  * @self: a `GtkNumericSorter`
  *
  * Gets the expression that is evaluated to obtain numbers from items.
@@ -613,7 +613,7 @@ gtk_numeric_sorter_get_expression (GtkNumericSorter *self)
 }
 
 /**
- * gtk_numeric_sorter_set_expression: (attributes org.gtk.Method.set_property=expression)
+ * gtk_numeric_sorter_set_expression:
  * @self: a `GtkNumericSorter`
  * @expression: (nullable) (transfer none): a `GtkExpression`
  *
@@ -646,7 +646,7 @@ gtk_numeric_sorter_set_expression (GtkNumericSorter *self,
 }
 
 /**
- * gtk_numeric_sorter_set_sort_order: (attributes org.gtk.Method.set_property=sort-order)
+ * gtk_numeric_sorter_set_sort_order:
  * @self: a `GtkNumericSorter`
  * @sort_order: whether to sort smaller numbers first
  *
@@ -671,7 +671,7 @@ gtk_numeric_sorter_set_sort_order (GtkNumericSorter *self,
 }
 
 /**
- * gtk_numeric_sorter_get_sort_order: (attributes org.gtk.Method.get_property=sort-order)
+ * gtk_numeric_sorter_get_sort_order:
  * @self: a `GtkNumericSorter`
  *
  * Gets whether this sorter will sort smaller numbers first.
